@@ -1,14 +1,16 @@
 package state_test
 
 import (
+	"io/fs"
 	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"os"
+	"path/filepath"
 	"testing"
 
-	"github.com/stretchr/testify/require"
-
+	"github.com/alecthomas/assert/v2"
+	"github.com/cashapp/hermit/cache"
 	"github.com/cashapp/hermit/sources"
 	"github.com/cashapp/hermit/state"
 	"github.com/cashapp/hermit/ui"
@@ -36,12 +38,17 @@ func NewStateTestFixture(t *testing.T) *StateTestFixture {
 }
 
 func (f *StateTestFixture) Clean() {
+	f.t.Helper()
 	if f.Server != nil {
 		f.Server.Close()
 	}
 	for r := range f.roots {
+		_ = filepath.Walk(r, func(path string, info fs.FileInfo, err error) error {
+			_ = os.Chmod(path, 0700) // nolint
+			return nil
+		})
 		err := os.RemoveAll(r)
-		require.NoError(f.t, err)
+		assert.NoError(f.t, err)
 	}
 }
 
@@ -49,7 +56,7 @@ func (f *StateTestFixture) State() *state.State {
 	root := f.root
 	if root == "" {
 		nroot, err := ioutil.TempDir("", "")
-		require.NoError(f.t, err)
+		assert.NoError(f.t, err)
 		root = nroot
 	}
 
@@ -57,10 +64,13 @@ func (f *StateTestFixture) State() *state.State {
 		f.Server = httptest.NewServer(f.handler)
 	}
 	f.roots[root] = true
+	client := f.Server.Client()
+	cache, err := cache.Open(root, nil, client, client)
+	assert.NoError(f.t, err)
 	sta, err := state.Open(root, state.Config{
 		Builtin: sources.NewBuiltInSource(vfs.InMemoryFS(nil)),
-	}, f.Server.Client(), f.Server.Client())
-	require.NoError(f.t, err)
+	}, cache)
+	assert.NoError(f.t, err)
 	return sta
 }
 
